@@ -59,14 +59,16 @@ maxControlsCap <- function(distance, min.controls = NULL, solver = "")
 
     # MMF: this check is probably not required anymore: the prepareMatching()
     # method should take care of things that are entirely unmatchable.
-    tdm <- (p > 0) / (p < Inf)
+    tdm <- 1 + (p > 0) / (p < Inf)
     tdm <- matrix(tdm, length(trnl), length(tcnl), dimnames = list(trnl, tcnl))
 
-    # FEASIBILITY CHECK -- temp depends on whether problem requires flipping
     ncol <- length(tcnl)
     nrow <- length(trnl)
 
-    temp <- SubDivStrat(rownames = trnl, colnames = tcnl, distspec = tdm,
+    nodes  <- nodes_shell_fmatch(rownames = trnl, colnames = tcnl)
+    t_nodes  <- nodes_shell_fmatch(rownames = tcnl, colnames = trnl)
+    # FEASIBILITY CHECK -- temp depends on whether problem requires flipping
+    temp <- solve_reg_fm_prob(node_info=nodes, distspec = tdm,
       max.cpt = min(tlmxc, ncol),
       min.cpt = max(tgmnc, 1/nrow), tolerance=.5,
       omit.fraction = NULL, solver = solver)
@@ -93,7 +95,9 @@ maxControlsCap <- function(distance, min.controls = NULL, solver = "")
 # SHOULD TLMXC ALSO BE SET TO ONE OR LESS?
         ncol <- length(trnl)
           nrow <- length(tcnl)
-          temp <- SubDivStrat(rownames=tcnl, colnames=trnl, distspec=t(tdm),
+          temp <-
+              solve_reg_fm_prob(node_info=t_nodes,
+                                distspec=t(tdm),
               max.cpt=min(1/tgmnc, ncol), min.cpt=1,
               tolerance=.5, omit.fraction=
                               switch(1+is.na(omf), -omf, NULL),
@@ -109,8 +113,7 @@ maxControlsCap <- function(distance, min.controls = NULL, solver = "")
         {
           tlmxc <-
             optimize( function(invlmxc) {
-                ifelse(!all(is.na(SubDivStrat(rownames = tcnl,
-                                        colnames = trnl,
+                ifelse(!all(is.na(solve_reg_fm_prob(node_info=t_nodes,
                                         distspec = t(tdm),
                                         max.cpt = min(1/tgmnc, length(trnl)),
                                         min.cpt = invlmxc,
@@ -134,7 +137,7 @@ maxControlsCap <- function(distance, min.controls = NULL, solver = "")
         {
           tlmxc <- ceiling(
               optimize( function(lmxc1, rown1, coln1, dist1, gmnc1, omf1) {
-                ifelse(!all(is.na(SubDivStrat( rownames=rown1, colnames=coln1, distspec=dist1,
+                ifelse(!all(is.na(solve_reg_fm_prob(node_info=nodes, distspec=dist1,
                       min.cpt=max(gmnc1, 1/length(rown1)), max.cpt=lmxc1,
                       tolerance=.5, omit.fraction= switch(1+is.na(omf), omf,
                         NULL), solver = solver )$cells)),
